@@ -14,17 +14,33 @@ import socket
 class UdpLocator:
     """UDP locator class."""
 
-    def locate(self, identifier='ALL', ipv4_only=True, verbose=False):
+    def locate(self, identifier='ALL', ipv4_only=True, verbose=False,
+               one_response_enough=False, **kwargs):
         """Locate Light Conversion devices on the LAN.
 
-    Locate Light Conversion LAN devices using UDP multicasts. All host IP
-    interfaces are uses as well as localhost.
+        Locate Light Conversion LAN devices using UDP multicasts. All host IP
+        interfaces are used as well as localhost which is needed when probing
+        servers running on the same machine as this program.
 
-    The following devices are supported:
-        Topas4 Server, PowerMeter, EthMotorBoard
+        The following devices are currenly supported:
+            Topas4 Server, PowerMeter, EthMotorBoard
 
-    Other devices may or may not be supported.
-    """
+        Other devices may or may not be supported.
+
+        Parameters
+        ----------
+        identifier : string, default: 'ALL'
+            The identifier is used to limit the scope of devices that are
+            supposed to respond to the multicast. All devices must respond to
+            'ALL'. Some devices have device-specific identifiers.
+        ipv4_only : boolean, default: True
+            If true, skip interfacing having IPv6 addresses.
+        verbose : boolean, default: True
+            If true, provide more information. Useful for troubleshooting.
+        one_response_enough : boolean, default: True
+            If true, stop scanning interfaces after the first valid response is
+            received. Useful when working locally with just a single device.
+        """
         if verbose:
             print("Running UDP locator for identifier {:}".format(identifier))
 
@@ -107,6 +123,12 @@ class UdpLocator:
                 print("Total number of devices: {:}".format(
                     len(unique_devices)))
 
+            if one_response_enough and len(unique_devices) > 0:
+                if verbose:
+                    print("One response is considered enough, skipping the "
+                          "remaining interfaces.")
+                break
+
         return unique_devices
 
 
